==> haskell-text-printer-0.5.0.2-162-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-printer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-printer
version:              0.5.0.2
visibility:           public
id:                   text-printer-0.5.0.2-JxkE8OqRIHG5XwENgS7oN4
key:                  text-printer-0.5.0.2-JxkE8OqRIHG5XwENgS7oN4
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/text-printer
synopsis:             Abstract interface for text builders/printers.
description:
    This package provides an interface for injecting text into monoids such as
    builders and printers.

category:             Text
abi:                  cddbe20637091fdaabc81ec842fe0002
exposed:              True
exposed-modules:
    Text.Printer Text.Printer.Fractional Text.Printer.Integral

import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-printer-0.5.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-printer-0.5.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-printer-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-printer
hs-libraries:         HStext-printer-0.5.0.2-JxkE8OqRIHG5XwENgS7oN4
depends:
    base-4.17.2.1 bytestring-0.11.5.3 pretty-1.1.3.6 text-2.0.2
    text-latin1-0.3.1-6Actri57WbGEwLgpDMcMNu

haddock-interfaces:
    /usr/share/doc/haskell-text-printer/html/text-printer.haddock

haddock-html:         /usr/share/doc/haskell-text-printer/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-printer-0.5.0.2-163-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-printer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-printer
version:              0.5.0.2
visibility:           public
id:                   text-printer-0.5.0.2-3h9iZoVOvGhFSnMk2oo230
key:                  text-printer-0.5.0.2-3h9iZoVOvGhFSnMk2oo230
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/text-printer
synopsis:             Abstract interface for text builders/printers.
description:
    This package provides an interface for injecting text into monoids such as
    builders and printers.

category:             Text
abi:                  3ffcb63df860112a4f50d8e1b28d90d0
exposed:              True
exposed-modules:
    Text.Printer Text.Printer.Fractional Text.Printer.Integral

import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-printer-0.5.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-printer-0.5.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-printer-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-printer
hs-libraries:         HStext-printer-0.5.0.2-3h9iZoVOvGhFSnMk2oo230
depends:
    base-4.17.2.1 bytestring-0.11.5.3 pretty-1.1.3.6 text-2.0.2
    text-latin1-0.3.1-IuJ9J3K0yPv568GaZFCbOh

haddock-interfaces:
    /usr/share/doc/haskell-text-printer/html/text-printer.haddock

haddock-html:         /usr/share/doc/haskell-text-printer/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
